use leptos::*;
use leptos_router::*;

#[component]
pub fn AddSeries() -> impl IntoView {
    let add_series = expect_context::<Action<AddSeries, Result<(), ServerFnError>>>();
    view! {
        <div class="card p-3">
            <div class="card-heading">
                <A href="/"
                    attr:class="btn btn-close"
                    attr:style="float: right;"
                >
                    <span style="display: none;">x</span>
                </A>
                <h2>New Series</h2>
            </div>
            <div class="card-body">
                <ActionForm action=add_series>
                    <div class="input-group mb-3">
                        <label class="input-group-text" for="name">Name</label>
                        <input type="text"
                            name="name"
                            class="form-control"
                        />
                    </div>
                    <div class="input-group mb-3">
                        <label class="input-group-text" for="source">Source Link</label>
                        <input type="text"
                            name="source"
                            class="form-control"
                        />
                    </div>
                    <div class="input-group mb-3">
                        <label class="input-group-text" for="imdb">IMDB Link</label>
                        <input type="text"
                            name="imdb"
                            class="form-control"
                        />
                    </div>
                    <div class="input-group mb-3">
                        <label class="input-group-text" for="wikipedia">Wikipedia Link</label>
                        <input type="text"
                            name="wikipedia"
                            class="form-control"
                        />
                    </div>
                    <div>
                        <input type="submit"
                            class="btn btn-primary"
                            value="Add"
                        />
                    </div>
                </ActionForm>
            </div>
        </div>
    }
}

#[server(AddSeries)]
pub async fn add_series(
    name: String,
    source: String,
    imdb: String,
    wikipedia: String,
) -> Result<(), ServerFnError> {
    use crate::db::load_statement;
    use sqlx::{Pool, Postgres};
    let pool = expect_context::<Pool<Postgres>>();

    let s = load_statement("insert_series.sql");
    sqlx::query(&s)
        .persistent(true)
        .bind(name)
        .bind(source)
        .bind(if imdb.is_empty() { None } else { Some(imdb) })
        .bind(if wikipedia.is_empty() {
            None
        } else {
            Some(wikipedia)
        })
        .execute(&pool)
        .await?;

    leptos_axum::redirect("/");

    Ok(())
}
